.. include:: ../../README.rst

.. note::

   This project is under active development.


Contents
--------

.. toctree::
    :maxdepth: 3

    installation
    usage/index
    api/index
    changelog
    license
    contributing
